@@ -20,6 +20,7 @@ from .literals import (
     ArtifactPackagingType,
     ArtifactsTypeType,
     AuthTypeType,
+    BatchReportModeTypeType,
     BucketOwnerAccessType,
     BuildBatchPhaseTypeType,
     BuildPhaseTypeType,
@@ -33,6 +34,7 @@ from .literals import (
     LogsConfigStatusTypeType,
     PlatformTypeType,
     ProjectSortByTypeType,
+    ProjectVisibilityTypeType,
     ReportCodeCoverageSortByTypeType,
     ReportExportConfigTypeType,
     ReportGroupSortByTypeType,
@@ -190,6 +192,8 @@ __all__ = (
     "TestReportSummaryTypeDef",
     "UpdateProjectInputRequestTypeDef",
     "UpdateProjectOutputTypeDef",
+    "UpdateProjectVisibilityInputRequestTypeDef",
+    "UpdateProjectVisibilityOutputTypeDef",
     "UpdateReportGroupInputRequestTypeDef",
     "UpdateReportGroupOutputTypeDef",
     "UpdateWebhookInputRequestTypeDef",
@@ -1277,6 +1281,7 @@ ProjectBuildBatchConfigTypeDef = TypedDict(
         "combineArtifacts": bool,
         "restrictions": "BatchRestrictionsTypeDef",
         "timeoutInMins": int,
+        "batchReportMode": BatchReportModeTypeType,
     },
     total=False,
 )
@@ -1403,6 +1408,9 @@ ProjectTypeDef = TypedDict(
         "fileSystemLocations": List["ProjectFileSystemLocationTypeDef"],
         "buildBatchConfig": "ProjectBuildBatchConfigTypeDef",
         "concurrentBuildLimit": int,
+        "projectVisibility": ProjectVisibilityTypeType,
+        "publicProjectAlias": str,
+        "resourceAccessRole": str,
     },
     total=False,
 )
@@ -1856,6 +1864,39 @@ UpdateProjectOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredUpdateProjectVisibilityInputRequestTypeDef = TypedDict(
+    "_RequiredUpdateProjectVisibilityInputRequestTypeDef",
+    {
+        "projectArn": str,
+        "projectVisibility": ProjectVisibilityTypeType,
+    },
+)
+_OptionalUpdateProjectVisibilityInputRequestTypeDef = TypedDict(
+    "_OptionalUpdateProjectVisibilityInputRequestTypeDef",
+    {
+        "resourceAccessRole": str,
+    },
+    total=False,
+)
+
+
+class UpdateProjectVisibilityInputRequestTypeDef(
+    _RequiredUpdateProjectVisibilityInputRequestTypeDef,
+    _OptionalUpdateProjectVisibilityInputRequestTypeDef,
+):
+    pass
+
+
+UpdateProjectVisibilityOutputTypeDef = TypedDict(
+    "UpdateProjectVisibilityOutputTypeDef",
+    {
+        "projectArn": str,
+        "publicProjectAlias": str,
+        "projectVisibility": ProjectVisibilityTypeType,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredUpdateReportGroupInputRequestTypeDef = TypedDict(
     "_RequiredUpdateReportGroupInputRequestTypeDef",
     {
